## v3.2.0 (2025-07-22)

### Feat

- enhance MQTT error handling and task lifecycle management

## [3.4.0](https://github.com/stkr22/private-assistant-commons-py/compare/v3.3.0...v3.4.0) (2025-07-24)


### Features

* enhance skill_logger with rich console and visual improvements ([ee87e5c](https://github.com/stkr22/private-assistant-commons-py/commit/ee87e5ca7f80a250ee6d1b26512eaf50f3f4a462))
* enhance skill_logger with rich console and visual improvements ([8261214](https://github.com/stkr22/private-assistant-commons-py/commit/8261214be9ae355c35b2f852d0819298ad3f8305))

## [3.3.0](https://github.com/stkr22/private-assistant-commons-py/compare/v3.2.0...v3.3.0) (2025-07-23)


### Features

* add Python version matrix testing and update supported versions ([8ea1a41](https://github.com/stkr22/private-assistant-commons-py/commit/8ea1a41f8ee67bc3130c138a9b5ede9ea2229cf3))
* add Python version matrix testing and update supported versions [AI] ([11d57bc](https://github.com/stkr22/private-assistant-commons-py/commit/11d57bc8711810050e78d99c403697c47a90e6e7))
* enhance MQTT error handling and task lifecycle management ([299bdbf](https://github.com/stkr22/private-assistant-commons-py/commit/299bdbf7e741be30ce1ccb26c7d99226a15c499c))

## v3.1.0 (2025-07-22)

### Feat

- implement performance and concurrency improvements

## v3.0.2 (2025-07-20)

### Fix

- failing test update uv workflow version
- failing tests
- :rotating_light: removed outdated type declaration
- **deps**: update dependency aiomqtt to ~=2.4.0

## v3.0.0 (2024-12-25)

### BREAKING CHANGE

- Removing AsyncTyper
fixes #12

### Refactor

- :fire: Removing async typer custom implementation using alternative implementation in skills
- :recycle: Updating copier template, migrating to uv

## v2.1.0 (2024-11-30)

### Feat

- :sparkles: Allowing skill prepartions to be executed

## v2.0.0 (2024-11-24)

### BREAKING CHANGE

- Renamed publish methods and made response an object;

### Feat

- Implement structure response and alert responses Fixes #9

## v1.1.2 (2024-11-13)

## v1.1.1 (2024-11-10)

## v1.1.0 (2024-10-03)

## v1.0.3 (2024-10-03)

## v1.0.2 (2024-10-03)

## v1.0.1 (2024-10-03)

## v1.0.0 (2024-10-03)

## v0.1.6 (2024-08-16)

## v0.1.5 (2024-08-16)

### Feat

- Refactor BaseSkill class, enhance unit tests, and implement centralized logging

## v0.1.4 (2024-08-04)

## v0.1.3 (2024-07-16)

## v0.1.2 (2024-07-14)

## v0.1.1 (2024-04-16)

## v0.1.0 (2024-04-15)
